.. _api:

API
=============

.. toctree::
   :maxdepth: 3

   gadma.Inference
   gadma.data
   gadma.models
   gadma.engines
   gadma.code_generator
   gadma.optimizers
   gadma.cli
   gadma.core
   gadma.utils
   gadma.run_ls_on_boot_data

